==> growingio-graphql-javasdk_2.12-0.0.1-sources.jar: io/growing/graphql/model/EventImportParameterResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for EventImportParameter
 */
@javax.annotation.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2020-12-22T15:45:57+0800"
)
public class EventImportParameterResponseProjection extends GraphQLResponseProjection {

    public EventImportParameterResponseProjection() {
    }

    @Override
    public EventImportParameterResponseProjection all$() {
        return all$(3);
    }

    @Override
    public EventImportParameterResponseProjection all$(int maxDepth) {
        this.tunnelId();
        this.timeRange();
        this.typename();
        return this;
    }

    public EventImportParameterResponseProjection tunnelId() {
        return tunnelId(null);
    }

    public EventImportParameterResponseProjection tunnelId(String alias) {
        fields.add(new GraphQLResponseField("tunnelId").alias(alias));
        return this;
    }

    public EventImportParameterResponseProjection timeRange() {
        return timeRange(null);
    }

    public EventImportParameterResponseProjection timeRange(String alias) {
        fields.add(new GraphQLResponseField("timeRange").alias(alias));
        return this;
    }

    public EventImportParameterResponseProjection typename() {
        return typename(null);
    }

    public EventImportParameterResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}

==> growingio-graphql-javasdk_2.12-0.0.2-sources.jar: io/growing/graphql/model/EventImportParameterResponseProjection.java <==
package io.growing.graphql.model;

import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseField;
import com.kobylynskyi.graphql.codegen.model.graphql.GraphQLResponseProjection;

/**
 * Response projection for EventImportParameter
 */
@javax.annotation.processing.Generated(
    value = "com.kobylynskyi.graphql.codegen.GraphQLCodegen",
    date = "2021-05-27T14:30:17+0800"
)
public class EventImportParameterResponseProjection extends GraphQLResponseProjection {

    public EventImportParameterResponseProjection() {
    }

    @Override
    public EventImportParameterResponseProjection all$() {
        return all$(3);
    }

    @Override
    public EventImportParameterResponseProjection all$(int maxDepth) {
        this.tunnelId();
        this.timeRange();
        this.typename();
        return this;
    }

    public EventImportParameterResponseProjection tunnelId() {
        return tunnelId(null);
    }

    public EventImportParameterResponseProjection tunnelId(String alias) {
        fields.add(new GraphQLResponseField("tunnelId").alias(alias));
        return this;
    }

    public EventImportParameterResponseProjection timeRange() {
        return timeRange(null);
    }

    public EventImportParameterResponseProjection timeRange(String alias) {
        fields.add(new GraphQLResponseField("timeRange").alias(alias));
        return this;
    }

    public EventImportParameterResponseProjection typename() {
        return typename(null);
    }

    public EventImportParameterResponseProjection typename(String alias) {
        fields.add(new GraphQLResponseField("__typename").alias(alias));
        return this;
    }


}
